@@ -18,7 +18,8 @@
 from unforward.emailclients.emailclient import EmailClient
 from unforward.errors import ExtractionError
 from bs4 import BeautifulSoup
-
+from pprint import pprint
+import datetime
 
 class OutlookExpressClient(EmailClient):
     """ Extracts originals from OutlookExpress clients"""
@@ -40,7 +41,9 @@ class OutlookExpressClient(EmailClient):
             blockquotes = parsed.html.body.find_all('blockquote')
             sender = blockquotes[0].a.get_text()
             body = ''.join(str(tag).strip() for tag in blockquotes[1].contents)
-            return {"body" : body, "sender" : sender}
+            date = datetime.datetime.strptime(str(blockquotes[0].find_all('b')[1].next_sibling).strip(), "%B %d, %Y at %I:%M:%S %p %Z")
+            
+            return {"body" : body, "sender" : sender, "date" : date}
         except Exception as e:
             raise ExtractionError("Given email did not parse as an outlook forward successfully: " + str(e))
         
