@@ -21,6 +21,7 @@ import json
 import sys
 from unforward.errors import NoForwardFoundError
 from unforward.errors import ExtractionError
+import logging
 
 def main():
     """ The main starting point for the unforward script."""
@@ -36,8 +37,10 @@ def main():
         result['date'] = result['date'].strftime(r"%Y-%m-%dT%H:%M:%S %z")
         print(json.dumps(result))
     except ExtractionError as e:
+        logging.exception("")
         exit(2)
     except NoForwardFoundError as e:
+        logging.exception("")
         exit(1)
     
 
